@@ -180,9 +180,8 @@ random_port = function(port = 4321L, host = getOption('servr.host', '127.0.0.1')
   # when the same port is tested on 127.0.0.1, which might be a bug of httpuv;
   # so we provide an option to test the availability of a port on 0.0.0.0 when
   # we intend to serve a site on 127.0.0.1
-  if (host == '127.0.0.1' && getOption('servr.test.0.0.0.0', FALSE))
-    host = '0.0.0.0'
-  for (p in ports) if (port_available(p, host)) {
+  test0 = host == '127.0.0.1' && getOption('servr.test.0.0.0.0', TRUE)
+  for (p in ports) if (port_available(p, host) && (!test0 || port_available(p, '0.0.0.0'))) {
     port = p
     break
   }
